function h = bmanalyzeInfo( varargin )
% BMANALYZEINFO(url) Returns image info of corresponding image 'url' from BrainMaps.org, including image
% height, width, number of tiles, and approximate computation time (assuming 1 sec per tile computation)
%
%   Notes
%   -------
%   To obtain image url's to use with BMANALYZE, use BMANALYZEGETPATHS, or
%   alternatively, find a brain dataset you
%   want to use at http://brainmaps.org, click on the 'Metadata' link, and
%   then click on 'Generate Paths' to generate a list of all url's for the
%   selected brain dataset.
%
%   Example
%   -------
%   Grab image info for brain image located at
%   http://brainmaps.org/HBP2/mus.musculus/cor/002-nissl/m08a/
%
%       bmanalyzeInfo('http://brainmaps.org/HBP2/mus.musculus/cor/002-nissl/m08a/');
%
%   See also BMANALYZE, BMANALYZEPLOT, BMANALYZEGETPATHS.
%
%   Copyright 2006 BrainMaps.org.

try
    url = varargin{1}
catch
	url = 'http://brainmaps.org/HBP2/mus.musculus/cor/002-nissl/m08a/'
end

a_pre=imread(strcat(url,'TileGroup0/0-0-0.jpg'));
figure,imagesc(a_pre),axis equal


url2=strcat(url,'ImageProperties.xml');

 

theStruct = parseChildNodes(xmlread(url2));

full_width=str2num(theStruct.Attributes(6).Value);
full_width_in_pixels=full_width
full_height=str2num(theStruct.Attributes(1).Value);
full_height_in_pixels=full_height
numtiles=str2num(theStruct.Attributes(3).Value)
tile_size=256;



num_resolutions_max = ceil(log(ceil(max(full_width,full_height)/tile_size))/log(2.0))
res=num_resolutions_max;
 
tiles_high=floor(full_height/(256*(2^(num_resolutions_max-res)) )) 
tiles_wide=floor(full_width/(256*(2^(num_resolutions_max-res)) )) 
            
total_tiles=tiles_high*tiles_wide

approximate_hours_of_computation_time=total_tiles/3600

            






%The functions below are for parsing XML



% ----- Subfunction PARSECHILDNODES -----
function children = parseChildNodes(theNode)
% Recurse over node children.
children = [];
if theNode.hasChildNodes
   childNodes = theNode.getChildNodes;
   numChildNodes = childNodes.getLength;
   allocCell = cell(1, numChildNodes);

   children = struct(             ...
      'Name', allocCell, 'Attributes', allocCell,    ...
      'Data', allocCell, 'Children', allocCell);

    for count = 1:numChildNodes
        theChild = childNodes.item(count-1);
        children(count) = makeStructFromNode(theChild);
    end
end

% ----- Subfunction MAKESTRUCTFROMNODE -----
function nodeStruct = makeStructFromNode(theNode)
% Create structure of node info.

nodeStruct = struct(                        ...
   'Name', char(theNode.getNodeName),       ...
   'Attributes', parseAttributes(theNode),  ...
   'Data', '',                              ...
   'Children', parseChildNodes(theNode));

if any(strcmp(methods(theNode), 'getData'))
   nodeStruct.Data = char(theNode.getData); 
else
   nodeStruct.Data = '';
end

% ----- Subfunction PARSEATTRIBUTES -----
function attributes = parseAttributes(theNode)
% Create attributes structure.

attributes = [];
if theNode.hasAttributes
   theAttributes = theNode.getAttributes;
   numAttributes = theAttributes.getLength;
   allocCell = cell(1, numAttributes);
   attributes = struct('Name', allocCell, 'Value', allocCell);

   for count = 1:numAttributes
      attrib = theAttributes.item(count-1);
      attributes(count).Name = char(attrib.getName);
      attributes(count).Value = char(attrib.getValue);
   end
end







            
            